@@ -1089,12 +1089,24 @@ def spectral_separation_routine(
         if vsini_A.ndim == 2:
             for i in range(0, vsini_A[0, :].size):
                 for j in range(0, vsini_A[:, 0].size):
-                    _, _, vsini_A[j, i], _, _, _ = get_fit_parameter_values(bf_fitres_A[j, i][0].params)
-                    _, _, vsini_B[j, i], _, _, _ = get_fit_parameter_values(bf_fitres_B[j, i][0].params)
+                    if rv_options.fitting_profile == 'RotBF':
+                        vsini_A[j, i] = bf_fitres_A[j, i][0].params['vsini'].value
+                        vsini_B[j, i] = bf_fitres_B[j, i][0].params['vsini'].value
+                    elif rv_options.fitting_profile == 'Gaussian':
+                        vsini_A[j, i] = bf_fitres_A[j, i][0].params['gaussian_sigma'].value
+                        vsini_B[j, i] = bf_fitres_B[j, i][0].params['gaussian_sigma'].value
+                    else:
+                        raise ValueError('Unknown fitting profile selected.')
         else:
             for i in range(0, vsini_A.size):
-                _, _, vsini_A[i], _, _, _ = get_fit_parameter_values(bf_fitres_A[i][0].params)
-                _, _, vsini_B[i], _, _, _ = get_fit_parameter_values(bf_fitres_B[i][0].params)
+                if rv_options.fitting_profile == 'RotBF':
+                    vsini_A[i] = bf_fitres_A[i][0].params['vsini'].value
+                    vsini_B[i] = bf_fitres_B[i][0].params['vsini'].value
+                elif rv_options.fitting_profile == 'Gaussian':
+                    vsini_A[i] = bf_fitres_A[i][0].params['gaussian_sigma'].value
+                    vsini_B[i] = bf_fitres_B[i][0].params['gaussian_sigma'].value
+                else:
+                    raise ValueError('Unknown fitting profile selected.')
         if options.adjust_vsini is True:
             rv_options.vsini_A = np.mean(vsini_A)
             rv_options.vsini_B = np.mean(vsini_B)
